@@ -715,4 +715,4 @@ def rotary_embedding(query: Optional[torch.Tensor], key: Optional[torch.Tensor],
     freq: torch.Tensor = shape_broadcast_freq(_query, freq)
     q: torch.Tensor = torch.view_as_real(_query * freq).flatten(3)
     k: torch.Tensor = torch.view_as_real(_key * freq).flatten(3)
-    return q.type_as(_query), k.type_as(_key)
+    return q.type_as(query), k.type_as(key)
